@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# -*- coding: utf-8 -*-
 
+from .distances import *
 from .metrics import *
-from .utilities import *
+from .utilities import *
\ No newline at end of file
